@@ -106,7 +106,7 @@ class APP:
             if k.startswith("out") and k[-1].isdigit():
                 result = self.outputArgs[k.replace("out",
                                                    "outputData")].dump(v)
-                for port, value in result.items():
+                for port, value in list(result.items()):
                     if port.startswith("out"):
                         port = port.replace(
                             "outputData",
